@@ -69,7 +69,7 @@ KEuroCalc::KEuroCalc(QWidget *parent, const char *name)
 		KMessageBox::error( 0, i18n( "Cannot load currencies.xml" ) );
 		exit(1);
 	}
-	readOptions( reference, currencyNum, rounding );
+	readOptions( reference, currencyNum, rounding, displayColor, splashScreen );
 
 	displayNewCurrency();
 	displayNewResult();
@@ -81,7 +81,10 @@ KEuroCalc::KEuroCalc(QWidget *parent, const char *name)
 	if (position < 0) position = 0;
 	CurrencyList->setCurrentItem( position );
 
-	setFixedSize(size());
+	ResultDisplay->setPaletteBackgroundColor(displayColor);
+	InputDisplay->setPaletteBackgroundColor(displayColor);
+	OperatorDisplay->setPaletteBackgroundColor(displayColor);
+
 	setFocusPolicy( StrongFocus );
 }
 
@@ -90,8 +93,22 @@ KEuroCalc::~KEuroCalc()
 {
 }
 
+// Is splash screen to be displayed ?
+bool KEuroCalc::readSplashScreen() const
+{
+	KConfig *config;
+	QString option;
+
+	config = KApplication::kApplication()->config();
+	config->setGroup("General");
+
+	option = config->readEntry("SplashScreen", "yes");
+
+	return option == "yes";
+}
+
 // Read options from preferences file
-void KEuroCalc::readOptions(int &oldReference, int &oldCurrency, int &oldRounding )
+void KEuroCalc::readOptions(int &oldReference, int &oldCurrency, int &oldRounding, QColor &oldDisplayColor, bool &oldSplashScreen) const
 {
 	KConfig *config;
 	QString option;
@@ -122,10 +139,16 @@ void KEuroCalc::readOptions(int &oldReference, int &oldCurrency, int &oldRoundin
 	else if (option == "NO_ROUNDING")
 		oldRounding = NO_ROUNDING;
 	else oldRounding = OFFICIAL_RULES;
+
+	option = config->readEntry("DiplayColor", "#C0FFFF");
+	oldDisplayColor.setNamedColor(option);
+
+	option = config->readEntry("SplashScreen", "yes");
+	oldSplashScreen = option == "yes";
 }
 
 // Write options to preferences file
-void KEuroCalc::writeOptions(int newReference, int newCurrency, int newRounding)
+void KEuroCalc::writeOptions(int newReference, int newCurrency, int newRounding, QColor newDisplayColor, bool newSplashScreen)
 {
 	KConfig *config;
 
@@ -156,15 +179,21 @@ void KEuroCalc::writeOptions(int newReference, int newCurrency, int newRounding)
 			config->writeEntry("Rounding", "NO_ROUNDING");
 	}
 
+	config->writeEntry("DiplayColor", newDisplayColor.name());
+
+	config->writeEntry("SplashScreen", newSplashScreen? "yes": "no");
+
 	config->sync();
 }
 
 // Set new preferences dialog
-void KEuroCalc::setPreferences(int newReference, int newCurrency, int newRounding)
+void KEuroCalc::setPreferences(int newReference, int newCurrency, int newRounding, QColor newDisplayColor, bool newSplashScreen)
 {
 	reference = newReference;
 	currencyNum = newCurrency;
 	rounding = newRounding;
+	displayColor = newDisplayColor;
+	splashScreen = newSplashScreen;
 
 	CurrencyList->clear();
 	initButtons();
